@@ -3,7 +3,7 @@
 use crate::{
     error::Error,
     file_stem_is_valid_txid,
-    solana::{FLOOR, SOLANA_MAIN_URL, SOL_AR_BASE_URL},
+    solana::{FLOOR, RATE, SOLANA_MAIN_URL, SOL_AR_BASE_URL},
     status::{OutputFormat, StatusCode},
     transaction::{Base64, Tag},
     update_bundle_statuses_stream, update_statuses_stream, upload_bundles_stream,
@@ -62,7 +62,8 @@ where
                     let blocks_len = data_len / BLOCK_SIZE + (data_len % BLOCK_SIZE != 0) as u64;
                     match with_sol {
                         true => {
-                            std::cmp::max((base + incremental * (blocks_len - 1)) * 0, FLOOR) + 5000
+                            std::cmp::max((base + incremental * (blocks_len - 1)) / RATE, FLOOR)
+                                + 5000
                         }
                         false => base + incremental * (blocks_len - 1),
                     }
@@ -83,7 +84,7 @@ where
                             data_len / BLOCK_SIZE + (data_len % BLOCK_SIZE != 0) as u64;
                         match with_sol {
                             true => {
-                                std::cmp::max((base + incremental * (blocks_len - 1)) * 0, FLOOR)
+                                std::cmp::max((base + incremental * (blocks_len - 1)) / RATE, FLOOR)
                                     + 5000
                             }
                             false => base + incremental * (blocks_len - 1),
@@ -283,6 +284,7 @@ pub async fn command_update_metadata<IP>(
     paths_iter: IP,
     manifest_path: PathBuf,
     link_file: bool,
+    update_image: bool,
 ) -> CommandResult
 where
     IP: Iterator<Item = PathBuf> + Send + Sync,
@@ -291,7 +293,12 @@ where
     let num_paths: usize = paths_vec.len();
 
     arweave
-        .update_metadata(paths_vec.into_iter(), manifest_path, link_file)
+        .update_metadata(
+            paths_vec.into_iter(),
+            manifest_path,
+            link_file,
+            update_image,
+        )
         .await?;
 
     println!("Successfully updated {} metadata files.", num_paths);
@@ -792,12 +799,14 @@ where
     .unwrap();
 
     // Update metadata with links to uploaded images.
+    // Assumes simple case of single image file - updates image link accordingly.
     println!("\n\nUpdating metadata with links from manifest...\n");
     command_update_metadata(
         &arweave,
         paths_vec.clone().into_iter(),
         asset_manifest_path,
         link_file,
+        true,
     )
     .await?;
 
@@ -977,29 +986,21 @@ pub async fn command_wallet_balance(
 }
 
 /// Writes metaplex link items used to create NFTs with candy machine program.
-pub async fn command_write_metaplex_items(
+pub async fn command_write_metaplex_items<IP>(
     arweave: &Arweave,
-    glob_str: &str,
-    manifest_str: &str,
+    paths_iter: IP,
+    manifest_path: PathBuf,
     link_file: bool,
-) -> CommandResult {
-    let paths_iter = glob(glob_str)?.filter_map(Result::ok);
-    let num_paths: usize = paths_iter.collect::<Vec<PathBuf>>().len();
-    let manifest_path = PathBuf::from(manifest_str);
-
+) -> CommandResult
+where
+    IP: Iterator<Item = PathBuf> + Send + Sync,
+{
     let metaplex_items_path = arweave
-        .write_metaplex_items(
-            glob(glob_str)?
-                .filter_map(Result::ok)
-                .map(|p| p.with_extension("json")),
-            manifest_path,
-            link_file,
-        )
+        .write_metaplex_items(paths_iter, manifest_path, link_file)
         .await?;
 
     println!(
-        "Successfully wrote metaplex items for {} metadata files to {}",
-        num_paths,
+        "Successfully wrote metaplex items for metadata files to {}.",
         metaplex_items_path.display().to_string()
     );
     Ok(())
