@@ -115,7 +115,7 @@ pub mod utils;
 use bundle::DataItem;
 use error::Error;
 use merkle::{generate_data_root, generate_leaves, resolve_proofs};
-use solana::{create_sol_transaction, get_sol_ar_signature, SigResponse, FLOOR};
+use solana::{create_sol_transaction, get_sol_ar_signature, SigResponse, FLOOR, RATE};
 use status::{BundleStatus, Filterable, Status, StatusCode};
 use transaction::{Base64, Chunk, FromUtf8Strs, Tag, ToItems, Transaction};
 
@@ -959,7 +959,7 @@ impl Arweave {
         sol_ar_url: Url,
         from_keypair: &Keypair,
     ) -> Result<(Transaction, SigResponse), Error> {
-        let lamports = std::cmp::max(&transaction.reward * 0, FLOOR);
+        let lamports = std::cmp::max(&transaction.reward / RATE, FLOOR);
 
         let mut sol_tx = create_sol_transaction(solana_url.clone(), from_keypair, lamports).await?;
         let mut resp = get_sol_ar_signature(
@@ -1570,17 +1570,29 @@ impl Arweave {
     pub async fn update_metadata_file(
         &self,
         file_path: PathBuf,
-        files_array: Vec<Value>,
-        image_link: String,
+        mut files_array: Vec<Value>,
+        image_link: Option<String>,
     ) -> Result<(), Error> {
         let data = fs::read_to_string(file_path.clone()).await?;
         let mut metadata: Value = serde_json::from_str(&data)?;
         let metadata = metadata.as_object_mut().unwrap();
-        let _ = metadata.insert("image".to_string(), Value::String(image_link));
 
-        let properties = metadata["properties"].as_object_mut().unwrap();
-        let _ = properties.insert("files".to_string(), Value::Array(files_array));
-        // let _ = metadata.insert("properties".to_string(), Value::Object(properties.clone()));
+        if let Some(image_link) = image_link {
+            metadata.insert("image".to_string(), Value::String(image_link));
+        }
+
+        let properties = if let Some(properties) = metadata.get_mut("properties") {
+            properties.as_object_mut().unwrap()
+        } else {
+            metadata.insert("properties".to_string(), json!({}));
+            metadata["properties"].as_object_mut().unwrap()
+        };
+
+        if let Some(files) = properties.get_mut("files") {
+            files.as_array_mut().unwrap().append(&mut files_array);
+        } else {
+            properties.insert("files".to_string(), Value::Array(files_array));
+        }
 
         fs::write(file_path, serde_json::to_string(&json!(metadata))?).await?;
         Ok(())
@@ -1591,6 +1603,7 @@ impl Arweave {
         paths_iter: IP,
         manifest_path: PathBuf,
         image_link_file: bool,
+        update_image_link: bool,
     ) -> Result<(), Error>
     where
         IP: Iterator<Item = PathBuf> + Send,
@@ -1608,25 +1621,32 @@ impl Arweave {
 
             try_join_all(paths_iter.map(|p| {
                 let path_object = manifest.get(&p.display().to_string()).unwrap();
-                let image_link = if image_link_file {
-                    format!(
-                        "https://arweave.net/{}/{}",
-                        manifest_id,
-                        &p.display().to_string()
-                    )
+                let image_link = if update_image_link {
+                    let link = if image_link_file {
+                        format!(
+                            "https://arweave.net/{}/{}",
+                            manifest_id,
+                            &p.display().to_string()
+                        )
+                    } else {
+                        format!(
+                            "https://arweave.net/{}",
+                            path_object["id"].as_str().unwrap()
+                        )
+                    };
+                    Some(link)
                 } else {
-                    format!(
-                        "https://arweave.net/{}",
-                        path_object["id"].as_str().unwrap()
-                    )
+                    None
                 };
                 let files_array = if image_link_file {
                     path_object["files"].as_array().unwrap().clone()
                 } else {
-                    vec![json!(format!(
-                        "https://arweave.net/{}",
-                        path_object["id"].as_str().unwrap()
-                    ))]
+                    vec![path_object["files"]
+                        .as_array()
+                        .unwrap()
+                        .get(0)
+                        .unwrap()
+                        .clone()]
                 };
                 self.update_metadata_file(p.with_extension("json"), files_array, image_link)
             }))
@@ -1659,31 +1679,32 @@ impl Arweave {
 
             let metadata = try_join_all(paths_iter.map(|p| self.read_metadata_file(p))).await?;
 
-            let items =
-                metadata
-                    .iter()
-                    .enumerate()
-                    .fold(serde_json::Map::new(), |mut m, (i, meta)| {
-                        let name = meta["metadata"]["name"].as_str().unwrap();
-                        let file_path = meta["file_path"].as_str().unwrap();
-                        let id = manifest
-                            .get(file_path)
-                            .unwrap()
-                            .get("id")
-                            .unwrap()
-                            .as_str()
-                            .unwrap();
-                        let link = if link_file {
-                            format!("https://arweave.net/{}/{}", manifest_id, file_path)
-                        } else {
-                            format!("https://arweave.net/{}", id)
-                        };
-                        m.insert(
-                            i.to_string(),
-                            json!({"name": name, "link": link, "onChain": false}),
-                        );
-                        m
-                    });
+            let items = metadata.iter().fold(serde_json::Map::new(), |mut m, meta| {
+                let name = meta["metadata"]["name"].as_str().unwrap();
+                let file_path = meta["file_path"].as_str().unwrap();
+                let id = manifest
+                    .get(file_path)
+                    .unwrap()
+                    .get("id")
+                    .unwrap()
+                    .as_str()
+                    .unwrap();
+                let link = if link_file {
+                    format!("https://arweave.net/{}/{}", manifest_id, file_path)
+                } else {
+                    format!("https://arweave.net/{}", id)
+                };
+                m.insert(
+                    PathBuf::from(file_path)
+                        .file_stem()
+                        .unwrap()
+                        .to_str()
+                        .unwrap()
+                        .to_string(),
+                    json!({"name": name, "link": link, "onChain": false}),
+                );
+                m
+            });
 
             let manifest_items_path = manifest_path
                 .parent()
